#include "config.h"

#include <qsettings.h>
#include <qcolordialog.h>
#include <qpushbutton.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qlayout.h>
#include <qdir.h>

void Config::save()
{
    QSettings set;
    set.setPath("Casio (J Patte)","Sprite Maker");
    set.writeEntry("/Settings/mode", m_mode);
    set.writeEntry("/Settings/lang", m_lang);
    set.writeEntry("/Settings/color", m_color.name());
	set.writeEntry("/Settings/trFile", m_trFile);
}

///////////////////////////////////////////////////////////////////////////////////////

void Config::chooseColor()
{
    QColor c = QColorDialog::getColor(m_color,this,"colordialog");
    if( c.isValid() ) m_color = c;
}

///////////////////////////////////////////////////////////////////////////////////////

Config::Config( QWidget* parent )
    : QDialog( parent, "Config", true )
{
    QVBoxLayout* ConfigLayout = new QVBoxLayout( this, 11, 6, "ConfigLayout"); 

    appGrpBox = new QGroupBox( this, "appGrpBox" );
    appGrpBox->setColumnLayout(0, Qt::Vertical );
    appGrpBox->layout()->setSpacing( 6 );
    appGrpBox->layout()->setMargin( 11 );
    QVBoxLayout* appGrpBoxLayout = new QVBoxLayout( appGrpBox->layout() );
    appGrpBoxLayout->setAlignment( Qt::AlignTop );

    tradBox = new QComboBox( FALSE, appGrpBox, "tradBox" );
    tradBox->setMinimumSize( QSize( 0, 24 ) );
    appGrpBoxLayout->addWidget( tradBox );

    colorBtn = new QPushButton( appGrpBox, "colorBtn" );
    colorBtn->setMinimumSize( QSize( 0, 30 ) );
    appGrpBoxLayout->addWidget( colorBtn );
    ConfigLayout->addWidget( appGrpBox );

    codeGrpBox = new QGroupBox( this, "codeGrpBox" );
    codeGrpBox->setColumnLayout(0, Qt::Vertical );
    codeGrpBox->layout()->setSpacing( 6 );
    codeGrpBox->layout()->setMargin( 11 );
    QVBoxLayout* codeGrpBoxLayout = new QVBoxLayout( codeGrpBox->layout() );
    codeGrpBoxLayout->setAlignment( Qt::AlignTop );

    asmBtn = new QRadioButton( codeGrpBox, "asmButton" );
    codeGrpBoxLayout->addWidget( asmBtn );

    cppBtn = new QRadioButton( "C/C++", codeGrpBox, "cppBtn" );
    codeGrpBoxLayout->addWidget( cppBtn );

    modeBox = new QComboBox( FALSE, codeGrpBox, "modeBox" );
    modeBox->setMinimumSize( QSize( 0, 24 ) );
    modeBox->insertItem( "Normal b/b" );
    modeBox->insertItem( "Normal w/w" );
    modeBox->insertItem( "DrawLib 1.3" );
    modeBox->insertItem( "DrawLib 1.4" );
    modeBox->insertItem( "gxLib 1.0" );
    codeGrpBoxLayout->addWidget( modeBox );
    ConfigLayout->addWidget( codeGrpBox );

    QHBoxLayout* layout2 = new QHBoxLayout( 0, 0, 6, "layout2"); 

    okBtn = new QPushButton( this, "okBtn" );
    okBtn->setMinimumSize( QSize( 0, 30 ) );
    layout2->addWidget( okBtn );

    cancelBtn = new QPushButton( this, "cancelBtn" );
    cancelBtn->setMinimumSize( QSize( 0, 30 ) );
    layout2->addWidget( cancelBtn );
    ConfigLayout->addLayout( layout2 );
    languageChange();
    resize( QSize(219, 266).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

	resize( QSize(239, 240).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

	QSettings set;
    set.setPath("Casio (J Patte)","Sprite Maker");
    m_mode = set.readNumEntry("/Settings/mode", 1);
    m_lang = set.readNumEntry("/Settings/lang", 1);
    m_color.setNamedColor( set.readEntry("/Settings/color","#ffff00") );


	QDir tradDir(ProgramPath + "Languages");
	m_tradList = tradDir.entryList("*.qm");
	for(QStringList::Iterator i = m_tradList.begin(); i != m_tradList.end(); i++)
	{
		*i = (*i).section('.',0,0);
        tradBox->insertItem( *i );
	}

    m_trFile = set.readEntry("/Settings/trFile", "English");
	
	modeBox->setCurrentItem(m_mode);
	tradBox->setCurrentItem(m_tradList.findIndex(m_trFile));
	asmBtn->setChecked(m_lang==0);
	cppBtn->setChecked(m_lang==1);
	okBtn->setFocus();

		    // signals and slots connections
    connect( modeBox,	   SIGNAL( activated(int) ), SLOT( setCodeMode(int) ) );
    connect( tradBox,      SIGNAL( activated(int) ), SLOT( setTraduc(int) ) );
    connect( asmBtn,       SIGNAL( clicked() ),    SLOT( setLangAsm() ) );
    connect( cppBtn,       SIGNAL( clicked() ),    SLOT( setLangCpp() ) );
    connect( okBtn,		   SIGNAL( clicked() ),    SLOT( accept() )			);
    connect( cancelBtn,    SIGNAL( clicked() ),    SLOT( reject() )			);
    connect( colorBtn,     SIGNAL( clicked() ),    SLOT( chooseColor() )	);
}

///////////////////////////////////////////////////////////////////////////////////////

void Config::languageChange()
{
    setCaption( tr( "Settings", "Caption of the window" ) );
    appGrpBox->setTitle( tr( "Appearance", "Title of the first box" ) );
    colorBtn->setText( tr( "Mask Color", "Colour of the \'Mask Color\' button" ) );
    codeGrpBox->setTitle( tr( "Code Generation", "Title of the second box" ) );
    asmBtn->setText( tr( "Assembly", "Choice of Assembly language" ) );
    okBtn->setText( tr( "OK", "Caption of the \'OK\' button" ) );
    cancelBtn->setText( tr( "&Cancel", "Caption of the \'Cancel\' button" ) );
    cancelBtn->setAccel( QKeySequence( tr( "Alt+C", "Accelerator for the \'Cancel\' button" ) ) );
}

///////////////////////////////////////////////////////////////////////////////////////



