#ifndef __HANDLER
#define __HANDLER

#include "main.h"

#include <qvariant.h>
#include <qmainwindow.h>
#include <qapplication.h>
#include <qtable.h>
#include <qdragobject.h> 
#include <qstring.h>
#include <qpainter.h>
#include <qpalette.h> 
#include <qrect.h>
#include <qpixmap.h>
#include <qstringlist.h>
#include <qlabel.h>

#include "coder.h"

class QAction;
class QTranslator;

class Sprite;
class MyRecentFilesHdlr;

///////////////////////////////////////////////////////////////////////////////////////

class DropTable : public QTable
{
	Q_OBJECT
public:
	DropTable(QWidget* parent, const char* name) : QTable(parent,name) {}

public slots:
	void dragEnterEvent(QDragEnterEvent* event)
		{ event->accept( QTextDrag::canDecode(event) ); }

	void dropEvent(QDropEvent* event)
	{
		QString dropped;
		if( ! QTextDrag::decode(event,dropped) ) return;
		emit newDrop(dropped);
	}

signals:
	void newDrop(QString);
};

///////////////////////////////////////////////////////////////////////////////////////

class DrawItem : public QTableItem
{
public:

	DrawItem(QTable* table) : QTableItem(table, Never) {}
	virtual QPixmap pixmap() const { return m_pix; }
	virtual void setPixmap(const QPixmap & p ) { m_pix = p; }
	virtual void paint(QPainter * p, const QColorGroup & cg, const QRect & cr, bool selected );
	virtual QSize sizeHint() const;

protected:
	QPixmap m_pix;
};

///////////////////////////////////////////////////////////////////////////////////////

class Handler : public QMainWindow
{
    Q_OBJECT

public:
    Handler( int argc, char ** argv, QTranslator* translator );
    ~Handler();

signals:
	void modeChanged(int);

public slots:
    void fileNew();
    void fileOpen();
	void openCSPfile(QString file);
	bool fileClose();
	void fileSave();
    void fileSaveAs();
	void fileImport();
	void fileImportBMP();
	void fileExport();
	void fileExit() { close(); }
    void codeAll() { Coder coder(&m_liste,this,m_cspName); coder.exec(); }
    void helpAbout();
	void editCurrentSprite();
	void moveCurrentSpriteDown();
	void moveCurrentSpriteUp();
	void deleteCurrentSprite();
	void editClickedSprite(int row,int,int,const QPoint&);
    void setValue(int row, int col);
	void updateRow(uint i);
	void updateRow(Sprite* spr) { NotifyModif(); updateRow(m_liste.find(spr)); }
	void activeRow(Sprite* spr) { spritesTable->setRowReadOnly(m_liste.find(spr),false); }
	void editPref();

	void dragEnterEvent(QDragEnterEvent* event);
	void dropEvent(QDropEvent* event);
	void addDroppedStuff(QString dropped);

protected slots:
	void languageChange();

protected:
	bool askForSave();
	bool okToClose();
	void addSprite(Sprite* spr, bool andEdit=true);
	void closeEvent(QCloseEvent*);
	void enableActions(bool oui);
	void NotifyModif();
	void setMode(int mode, int lang);

    QPtrList<Sprite> m_liste;
    DropTable* spritesTable;
	MyRecentFilesHdlr* m_RFHandler;
	QString m_cspName;
	bool m_modified;
	bool m_CSPloaded;
	QTranslator* m_pTranslator;

	QAction* fileExitAction;
	QAction* helpAboutAction;
	QAction* fileNewAction;
	QAction* fileImportAction;
	QAction* fileImportBMPAction;
	QAction* editCurAction;
	QAction* editPrefAction;
	QAction* fileOpenAction;
	QAction* fileCloseAction;
	QAction* fileSaveAction;
	QAction* fileSaveAsAction;
	QAction* fileExportAction;
	QAction* codeAction;
	QAction* moveCurUpAction;
	QAction* moveCurDownAction;
	QAction* deleteCurAction;
	QLabel* statNbreSprites;
	QLabel* statModeLang;

	QMenuBar * MenuBar;
	QToolBar * toolBar;
	QPopupMenu * fileMenu;
};

#endif

